@@ -69,7 +69,7 @@ class L7RuleController(base.BaseController):
         self._auth_validate_action(context, l7policy.project_id,
                                    constants.RBAC_GET_ALL)
 
-        db_l7rules, links = self.repositories.l7rule.get_all(
+        db_l7rules, links = self.repositories.l7rule.get_all_API_list(
             context.session, show_deleted=False, l7policy_id=self.l7policy_id,
             pagination_helper=pcontext.get(constants.PAGINATION_HELPER))
         result = self._convert_db_to_type(
@@ -84,6 +84,10 @@ class L7RuleController(base.BaseController):
         l7policy = self._get_db_l7policy(session, self.l7policy_id)
         listener_id = l7policy.listener_id
         load_balancer_id = l7policy.listener.load_balancer_id
+        # Check the parent is not locked for some reason (ERROR, etc.)
+        if l7policy.provisioning_status not in constants.MUTABLE_STATUSES:
+            raise exceptions.ImmutableObject(resource='L7Policy',
+                                             id=self.l7policy_id)
         if not self.repositories.test_and_set_lb_and_listeners_prov_status(
                 session, load_balancer_id,
                 constants.PENDING_UPDATE, constants.PENDING_UPDATE,
