@@ -19,6 +19,7 @@ from oslo_utils import uuidutils
 
 from octavia.common import constants
 import octavia.common.context
+from octavia.db import repositories
 from octavia.tests.functional.api.v2 import base
 
 
@@ -45,6 +46,7 @@ class TestL7Rule(base.BaseAPITest):
         self.l7rules_path = self.L7RULES_PATH.format(
             l7policy_id=self.l7policy_id)
         self.l7rule_path = self.l7rules_path + '/{l7rule_id}'
+        self.l7policy_repo = repositories.L7PolicyRepository()
 
     def test_get(self):
         l7rule = self.create_l7rule(
@@ -309,11 +311,25 @@ class TestL7Rule(base.BaseAPITest):
         self.set_lb_status(self.lb_id)
 
         l7rus = self.get(self.l7rules_path, params={
-            'fields': ['id', 'project_id']}).json
+            'fields': ['id', 'compare_type']}).json
         for l7ru in l7rus['rules']:
-            self.assertIn(u'id', l7ru.keys())
-            self.assertIn(u'project_id', l7ru.keys())
-            self.assertNotIn(u'description', l7ru.keys())
+            self.assertIn(u'id', l7ru)
+            self.assertIn(u'compare_type', l7ru)
+            self.assertNotIn(u'project_id', l7ru)
+
+    def test_get_one_fields_filter(self):
+        l7r1 = self.create_l7rule(
+            self.l7policy_id, constants.L7RULE_TYPE_PATH,
+            constants.L7RULE_COMPARE_TYPE_STARTS_WITH,
+            '/api').get(self.root_tag)
+        self.set_lb_status(self.lb_id)
+
+        l7ru = self.get(
+            self.l7rule_path.format(l7rule_id=l7r1.get('id')),
+            params={'fields': ['id', 'compare_type']}).json.get(self.root_tag)
+        self.assertIn(u'id', l7ru)
+        self.assertIn(u'compare_type', l7ru)
+        self.assertNotIn(u'project_id', l7ru)
 
     def test_get_all_filter(self):
         ru1 = self.create_l7rule(
@@ -423,6 +439,21 @@ class TestL7Rule(base.BaseAPITest):
         self.conf.config(group='api_settings', auth_strategy=auth_strategy)
         self.assertEqual(self.NOT_AUTHORIZED_BODY, api_l7rule)
 
+    def test_create_l7policy_in_error(self):
+        l7policy = self.create_l7policy(
+            self.listener_id, constants.L7POLICY_ACTION_REJECT)
+        l7policy_id = l7policy.get('l7policy').get('id')
+        self.set_lb_status(self.lb_id)
+        self.set_object_status(self.l7policy_repo, l7policy_id,
+                               provisioning_status=constants.ERROR)
+        api_l7rule = self.create_l7rule(
+            l7policy_id, constants.L7RULE_TYPE_HOST_NAME,
+            constants.L7RULE_COMPARE_TYPE_EQUAL_TO,
+            'www.example.com', status=409)
+        ref_msg = ('L7Policy %s is immutable and cannot be updated.' %
+                   l7policy_id)
+        self.assertEqual(ref_msg, api_l7rule.get('faultstring'))
+
     def test_create_path_rule(self):
         api_l7rule = self.create_l7rule(
             self.l7policy_id, constants.L7RULE_TYPE_PATH,
